## [2.0.4] - 2020-05-1
### Fixed
- Migrate interfaces and notification into services

## [2.0.3] - 2020-04-25
### Fixed
- Use user path or url in tentacles requirements

## [2.0.2] - 2020-04-13
### Fixed
- Crash when missing config folder

## [2.0.1] - 2020-04-10
### Added
- Dev mode

### Fixed
- Import issues
- Logger issues

### Removed
- Websocket tentacle type

Changelog for 2.0.0
====================
*Released date : March 31 2020*

Total rework of the OctoBot Tentacles Manager for OctoBot 0.4
# New feature :
    - APIs and CLI for each action
    - Async file management
    - Tentacles packages management
    - Tentacles configuration management
    - Tentacles loading management
    
Changelog for 1.0.11
====================
*Released date : June 2 2019*

# New feature :
    - Now store tentacles config schemas as well as tentacles config in default folder
# Bug fix :
    - Fixed config file sometimes not created on tentacles update

Changelog for 1.0.10
====================
*Released date : Mai 8 2019*

# New feature :
    - Fixed import error

Changelog for 1.0.9
====================
*Released date : Mai 5 2019*

# New feature :
    - Handle config schema
   
Changelog for 1.0.8
====================
*Released date : April 14 2019*

# New feature :
    - Log hotfix
   
Changelog for 1.0.7
====================
*Released date : April 14 2019*

# New feature :
    - Now do not display in dev tentacles when update or uninstall if dev mode is not activated

Changelog for 1.0.6
====================
*Released date : April 13 2019*

# New feature :
    - Install now only reset tentacle config file if config file is missing

Changelog for 1.0.5
====================
*Released date : February 17 2019*

# New feature :
    - Can now specify a github branch using default_git_branch argument in parse_commands or by adding the branch argument in command argument in parse_commands
====================
*Released date : February 7 2019*

# Bug fixes :
    - Fix tentacle creator

Changelog for 1.0.3
====================
*Released date : February 7 2019*

# Bug fixes :
    - Fix init file creation & update
